@@ -15,7 +15,7 @@ class Logger(object):
         return self.wrapped_function
 
     def wrapped_function(self, event, context):
-        timeout_notification = self.add_logging_on_timeout(context)
+        timer = self.add_logging_on_timeout(event, context)
         try:
             logging.debug(event)
             response = self.function(event, context)
@@ -25,12 +25,15 @@ class Logger(object):
             logging.exception(ex.message)
             raise
         finally:
-            if timeout_notification: timeout_notification.cancel()
+            if timer: timer.cancel()
 
-    def add_logging_on_timeout(self, context):
+    def timeout_notification(self, event, context, **kwargs):
+        logging.error('Execution is about to timeout.', **kwargs)
+
+    def add_logging_on_timeout(self, event, context):
         if hasattr(context, 'get_remaining_time_in_millis'):
             seconds = (context.get_remaining_time_in_millis() / 1000.00) - 0.5
-            timer = threading.Timer(seconds, logging.error, args=["Execution is about to timeout."])
+            timer = threading.Timer(seconds, self.timeout_notification, args=[event, context])
             timer.start()
             return timer
         else:
